@@ -1,6 +1,9 @@
 # -*- coding: utf-8 -*-
-import re
+from __future__ import unicode_literals
+
 import os
+
+
 extensions = [
     'sphinx.ext.autodoc',
     'sphinx.ext.autosummary',
@@ -17,16 +20,17 @@ if os.getenv('SPELLCHECK'):
 
 source_suffix = '.rst'
 master_doc = 'index'
-project = u'redis-lock'
-copyright = u'2014, Ionel Cristian Mărieș'
-year = u'2014'
-author = u'Ionel Cristian Maries'
+project = 'redis-lock'
+year = '2013-2015'
+author = 'Ionel Cristian Mărieș'
 copyright = '{0}, {1}'.format(year, author)
-version = release = u'2.2.0'
-
+version = release = '2.3.0'
 import sphinx_py3doc_enhanced_theme
 html_theme = "sphinx_py3doc_enhanced_theme"
 html_theme_path = [sphinx_py3doc_enhanced_theme.get_html_theme_path()]
+html_theme_options = {
+    'githuburl': 'https://github.com/ionelmc/python-redis-lock/'
+}
 
 pygments_style = 'trac'
 templates_path = ['.']
@@ -37,6 +41,3 @@ html_sidebars = {
    '**': ['searchbox.html', 'globaltoc.html', 'sourcelink.html'],
 }
 html_short_title = '%s-%s' % (project, version)
-html_theme_options = {
-    'githuburl': 'https://github.com/ionelmc/python-redis-lock/'
-}
