@@ -6,17 +6,23 @@ import time
 from collections import defaultdict
 
 import pytest
-from process_tests import dump_on_error
 from process_tests import TestProcess
+from process_tests import dump_on_error
 from process_tests import wait_for_strings
+
 from redis import StrictRedis
 
-from redis_lock import Lock, AlreadyAcquired, NotAcquired, InterruptableThread
+from redis_lock import AlreadyAcquired
+from redis_lock import InterruptableThread
+from redis_lock import InvalidTimeout
+from redis_lock import Lock
+from redis_lock import NotAcquired
+from redis_lock import TimeoutTooLarge
+from redis_lock import TimeoutNotUsable
 from redis_lock import reset_all
-
+from conf import HELPER
 from conf import TIMEOUT
 from conf import UDS_PATH
-from conf import HELPER
 
 
 @pytest.yield_fixture
@@ -26,8 +32,9 @@ def redis_server(scope='module'):
     except OSError:
         pass
     with TestProcess('redis-server', '--port', '0', '--unixsocket', UDS_PATH) as process:
-        wait_for_strings(process.read, TIMEOUT, "Running")
-        yield process
+        with dump_on_error(process.read):
+            wait_for_strings(process.read, TIMEOUT, "Running")
+            yield process
 
 
 @pytest.fixture(scope='function')
@@ -63,6 +70,59 @@ def test_no_block(conn):
                 )
 
 
+def test_timeout(conn):
+    with Lock(conn, "foobar"):
+        lock = Lock(conn, "foobar")
+        assert lock.acquire(timeout=1) == False
+
+
+def test_timeout_expire(conn):
+    with Lock(conn, "foobar", expire=1):
+        lock = Lock(conn, "foobar")
+        assert lock.acquire(timeout=2)
+
+
+def test_timeout_expire_with_renewal(conn):
+    with Lock(conn, "foobar", expire=1, auto_renewal=True):
+        lock = Lock(conn, "foobar")
+        assert lock.acquire(timeout=2) == False
+
+
+def test_timeout_acquired(conn):
+    with TestProcess(sys.executable, HELPER, 'test_timeout') as proc:
+        with dump_on_error(proc.read):
+            name = 'lock:foobar'
+            wait_for_strings(
+                proc.read, TIMEOUT,
+                'Getting %r ...' % name,
+                'Got lock for %r.' % name,
+            )
+            lock = Lock(conn, "foobar")
+            assert lock.acquire(timeout=2)
+
+
+def test_not_usable_timeout(conn):
+    lock = Lock(conn, "foobar")
+    with pytest.raises(TimeoutNotUsable):
+        lock.acquire(blocking=False, timeout=1)
+
+
+def test_expire_less_than_timeout(conn):
+    lock = Lock(conn, "foobar", expire=1)
+    with pytest.raises(TimeoutTooLarge):
+        lock.acquire(blocking=True, timeout=2)
+
+
+def test_invalid_timeout(conn):
+    lock = Lock(conn, "foobar")
+    with pytest.raises(InvalidTimeout):
+        lock.acquire(blocking=True, timeout=0)
+
+    lock = Lock(conn, "foobar")
+    with pytest.raises(InvalidTimeout):
+        lock.acquire(blocking=True, timeout=-1)
+
+
 def test_expire(conn):
     with Lock(conn, "foobar", expire=TIMEOUT/4):
         with TestProcess(sys.executable, HELPER, 'test_expire') as proc:
@@ -137,6 +197,7 @@ def test_no_overlap(redis_server):
                             print("[%s/%s]" % (event, other))
                             raise
 
+
 def test_reset(conn):
     with Lock(conn, "foobar") as lock:
         lock.reset()
@@ -182,6 +243,7 @@ def test_bogus_release(conn):
     pytest.raises(NotAcquired, lock.release)
     lock.release(force=True)
 
+
 def test_release_from_nonblocking_leaving_garbage(conn):
     for _ in range(10):
         lock = Lock(conn, 'release_from_nonblocking')
@@ -189,16 +251,19 @@ def test_release_from_nonblocking_leaving_garbage(conn):
         lock.release()
         assert conn.llen('lock-signal:release_from_nonblocking') == 1
 
+
 def test_no_auto_renewal(conn):
     lock = Lock(conn, 'lock_renewal', expire=3, auto_renewal=False)
     assert lock._lock_renewal_interval is None
     lock.acquire()
     assert lock._lock_renewal_thread is None, "No lock refresh thread should have been spawned"
 
+
 def test_auto_renewal_bad_values(conn):
     with pytest.raises(ValueError):
         Lock(conn, 'lock_renewal', expire=None, auto_renewal=True)
 
+
 def test_auto_renewal(conn):
     lock = Lock(conn, 'lock_renewal', expire=3, auto_renewal=True)
     lock.acquire()
